#[non_exhaustive]pub struct DeleteWorkGroupInputBuilder { /* private fields */ }Expand description
A builder for DeleteWorkGroupInput.
Implementations
Sourceimpl DeleteWorkGroupInputBuilder
impl DeleteWorkGroupInputBuilder
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The unique name of the workgroup to delete.
This field is required.Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The unique name of the workgroup to delete.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The unique name of the workgroup to delete.
Sourcepub fn recursive_delete_option(self, input: bool) -> Self
pub fn recursive_delete_option(self, input: bool) -> Self
The option to delete the workgroup and its contents even if the workgroup contains any named queries, query executions, or notebooks.
Sourcepub fn set_recursive_delete_option(self, input: Option<bool>) -> Self
pub fn set_recursive_delete_option(self, input: Option<bool>) -> Self
The option to delete the workgroup and its contents even if the workgroup contains any named queries, query executions, or notebooks.
Sourcepub fn get_recursive_delete_option(&self) -> &Option<bool>
pub fn get_recursive_delete_option(&self) -> &Option<bool>
The option to delete the workgroup and its contents even if the workgroup contains any named queries, query executions, or notebooks.
Sourcepub fn build(self) -> Result<DeleteWorkGroupInput, BuildError>
pub fn build(self) -> Result<DeleteWorkGroupInput, BuildError>
Consumes the builder and constructs a DeleteWorkGroupInput.
Sourceimpl DeleteWorkGroupInputBuilder
impl DeleteWorkGroupInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteWorkGroupOutput, SdkError<DeleteWorkGroupError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteWorkGroupOutput, SdkError<DeleteWorkGroupError, HttpResponse>>
Sends a request with this input using the given client.